@@ -128,6 +128,11 @@ public class GVRKUms
          */
         public String id;
         
+        /**
+         * NUR BEI CAMT: Ende-zu-Ende-Referenz (EREF)
+         */
+        public String endToEndId;
+        
         /**
          * NUR BEI CAMT: Der Purpose-Code der Buchung.
          */
@@ -245,6 +250,16 @@ public class GVRKUms
     private List<BTag> tageMT940;
     private List<BTag> tageMT942;
 
+    /**
+     * Die originale empfangene CAMT-Datei mit den gebuchten Umsaetzen.
+     */
+    public String camtBooked;
+    
+    /**
+     * Die originale empfangene CAMT-Datei mit den Vormerkbuchungen.
+     */
+    public String camtNotBooked;
+
     private boolean parsed;
 
     /** Dieses Feld enthält einen String, der den nicht-auswertbaren Teil der Kontoauszüge
